@@ -20,9 +20,9 @@
 """Manages the default speech server for orca.  A script can use this
 as its speech server, or it can feel free to create one of its own."""
 
-__id__        = "$Id: speech.py 3882 2008-05-07 18:22:10Z richb $"
-__version__   = "$Revision: 3882 $"
-__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__id__        = "$Id: speech.py 3904 2008-05-19 18:43:44Z wwalker $"
+__version__   = "$Revision: 3904 $"
+__date__      = "$Date: 2008-05-19 14:43:44 -0400 (Mon, 19 May 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -31,6 +31,7 @@ log = logging.getLogger("speech")
 
 import time
 
+import chnames
 import debug
 import keynames
 import orca
@@ -197,7 +198,7 @@ def speakKeyEvent(event_string, eventType):
 
 def speakCharacter(character, acss=None):
     """Speaks a single character immediately.
-    
+
     Arguments:
     - character: text to be spoken
     - acss:      acss.ACSS instance; if None,
@@ -209,8 +210,9 @@ def speakCharacter(character, acss=None):
     if settings.silenceSpeech:
         return
 
-    debug.println(debug.LEVEL_INFO, "SPEECH OUTPUT: '" + character + "'")
-    log.info("SPEECH OUTPUT: '%s'" % character)
+    spokenCharacter = chnames.getCharacterName(character)
+    debug.println(debug.LEVEL_INFO, "SPEECH OUTPUT: '" + spokenCharacter + "'")
+    log.info("SPEECH OUTPUT: '%s'" % spokenCharacter)
 
     if _speechserver:
         _speechserver.speakCharacter(character, acss=acss)
